##  Step 1: Register as a Publisher
Follow these steps:
  1. Create a [GitLab![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgitlab.com%2F "https://gitlab.com/") account using the same email address that is associated with your SAP LeanIX user account. We use GitLab as a source code repository for both public and private custom reports.
If you're new to GitLab, refer to the [GitLab documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdocs.gitlab.com%2Fee%2Fuser%2F "https://docs.gitlab.com/ee/user/") to learn how to get started. Ensure to set up your environment according to best practices, such as by adding an SSH key.
  2. Sign in to the SAP LeanIX Store from your workspace. To do that, in the user profile menu, select Store.
  3. After signing in to the SAP LeanIX Store, click Publish, scroll down to the bottom of the page, then click Send Request.
  4. In the dialog that opens, enter your GitLab username, then click Submit Request.
     * If you're an SAP LeanIX partner, you need to sign the Store Content Provider Agreement to get your publisher request approved. This agreement covers topics such as report ownership and intellectual property. For any questions, please contact your SAP LeanIX Partner Manager.
     * If you're an SAP LeanIX customer, you can create custom reports for your own workspaces without needing a formal agreement. However, if you want to share reports with other customers, you'll need to sign the Store Content Provider Agreement. For any questions, please contact your Customer Success Manager.


You'll receive an email with further information regarding your request.
